@@ -410,6 +410,16 @@ set_property (GObject *object,
     }
 }
 
+static void
+example_csh_room_channel_close (ExampleCSHRoomChannel *self)
+{
+  if (!self->priv->closed)
+    {
+      self->priv->closed = TRUE;
+      tp_svc_channel_emit_closed (self);
+    }
+}
+
 static void
 dispose (GObject *object)
 {
@@ -420,11 +430,7 @@ dispose (GObject *object)
 
   self->priv->disposed = TRUE;
 
-  if (!self->priv->closed)
-    {
-      self->priv->closed = TRUE;
-      tp_svc_channel_emit_closed (self);
-    }
+  example_csh_room_channel_close (self);
 
   ((GObjectClass *) example_csh_room_channel_parent_class)->dispose (object);
 }
@@ -462,6 +468,33 @@ add_member (GObject *object,
   return TRUE;
 }
 
+static gboolean
+remove_member_with_reason (GObject *object,
+                           TpHandle handle,
+                           const gchar *message,
+                           guint reason,
+                           GError **error)
+{
+  ExampleCSHRoomChannel *self = EXAMPLE_CSH_ROOM_CHANNEL (object);
+
+  if (handle == self->group.self_handle)
+    {
+      /* TODO: if simulating a channel where the user is an operator, let them
+       * kick themselves (like in IRC), resulting in different "network"
+       * messages */
+
+      example_csh_room_channel_close (self);
+      return TRUE;
+    }
+  else
+    {
+      /* TODO: also simulate some channels where the user is an operator and
+       * can kick people */
+      g_set_error (error, TP_ERRORS, TP_ERROR_PERMISSION_DENIED,
+          "You can't eject other users from this channel");
+      return FALSE;
+    }
+}
 
 static void
 example_csh_room_channel_class_init (ExampleCSHRoomChannelClass *klass)
@@ -558,6 +591,9 @@ example_csh_room_channel_class_init (ExampleCSHRoomChannelClass *klass)
       G_STRUCT_OFFSET (ExampleCSHRoomChannelClass, group_class),
       add_member,
       NULL);
+  tp_group_mixin_class_allow_self_removal (object_class);
+  tp_group_mixin_class_set_remove_with_reason_func (object_class,
+      remove_member_with_reason);
   tp_group_mixin_init_dbus_properties (object_class);
 }
 
@@ -568,11 +604,7 @@ channel_close (TpSvcChannel *iface,
 {
   ExampleCSHRoomChannel *self = EXAMPLE_CSH_ROOM_CHANNEL (iface);
 
-  if (!self->priv->closed)
-    {
-      self->priv->closed = TRUE;
-      tp_svc_channel_emit_closed (self);
-    }
+  example_csh_room_channel_close (self);
 
   tp_svc_channel_return_from_close (context);
 }
