@@ -104,7 +104,7 @@ example_normalize_contact (TpHandleRepoIface *repo,
 {
   if (id[0] == '\0')
     {
-      g_set_error (error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+      g_set_error (error, TP_ERRORS, TP_ERROR_INVALID_HANDLE,
           "ID must not be empty");
       return NULL;
     }
