@@ -630,14 +630,19 @@ tp_connection_manager_got_protocols (TpConnectionManager *self,
   tp_connection_manager_continue_introspection (self);
 }
 
+static gboolean
+introspection_in_progress (TpConnectionManager *self)
+{
+  return self->priv->listing_protocols || self->priv->found_protocols != NULL;
+}
+
 static gboolean
 tp_connection_manager_idle_introspect (gpointer data)
 {
   TpConnectionManager *self = data;
 
   /* Start introspecting if we want to and we're not already */
-  if (!self->priv->listing_protocols &&
-      self->priv->found_protocols == NULL &&
+  if (!introspection_in_progress (self) &&
       (self->always_introspect ||
        self->info_source == TP_CM_INFO_SOURCE_NONE))
     {
@@ -673,8 +678,7 @@ tp_connection_manager_name_owner_changed_cb (TpDBusDaemon *bus,
       self->running = FALSE;
 
       /* cancel pending introspection, if any */
-      if (self->priv->listing_protocols ||
-          self->priv->pending_protocols != NULL)
+      if (introspection_in_progress (self))
         tp_connection_manager_end_introspection (self, &e);
 
       g_signal_emit (self, signals[SIGNAL_EXITED], 0);
@@ -823,6 +827,7 @@ parse_default_value (GValue *value,
       g_value_take_string (value, s);
       return (s != NULL);
 
+    case 'y':
     case 'q':
     case 'u':
     case 't':
@@ -841,6 +846,17 @@ parse_default_value (GValue *value,
               return TRUE;
             }
 
+          if (sig[0] == 'y')
+            {
+              if (v > G_MAXUINT8)
+                {
+                  return FALSE;
+                }
+
+              g_value_set_uchar (value, v);
+              return TRUE;
+            }
+
           if (v > G_MAXUINT32 || (sig[0] == 'q' && v > G_MAXUINT16))
             return FALSE;
 
@@ -884,10 +900,13 @@ parse_default_value (GValue *value,
     case 'o':
       s = g_key_file_get_string (file, group, key, NULL);
 
-      g_value_take_boxed (value, s);
+      if (s == NULL || !tp_dbus_check_valid_object_path (s, NULL))
+        {
+          g_free (s);
+          return FALSE;
+        }
 
-      if (s[0] != '/')
-        return FALSE;
+      g_value_take_boxed (value, s);
 
       return TRUE;
 
@@ -1088,6 +1107,8 @@ tp_connection_manager_idle_read_manager_file (gpointer data)
 {
   TpConnectionManager *self = TP_CONNECTION_MANAGER (data);
 
+  self->priv->manager_file_read_idle_id = 0;
+
   if (self->priv->protocols == NULL)
     {
       if (self->priv->manager_file != NULL &&
@@ -1117,11 +1138,15 @@ tp_connection_manager_idle_read_manager_file (gpointer data)
               DEBUG ("Got info from file");
               /* previously it must have been NONE */
               self->info_source = TP_CM_INFO_SOURCE_FILE;
+
+              g_object_ref (self);
               g_object_notify ((GObject *) self, "info-source");
 
               g_signal_emit (self, signals[SIGNAL_GOT_INFO], 0,
                   self->info_source);
               tp_connection_manager_ready_or_failed (self, NULL);
+              g_object_unref (self);
+
               goto out;
             }
         }
@@ -1140,8 +1165,6 @@ tp_connection_manager_idle_read_manager_file (gpointer data)
     }
 
 out:
-  self->priv->manager_file_read_idle_id = 0;
-
   return FALSE;
 }
 
@@ -1383,14 +1406,46 @@ tp_connection_manager_set_property (GObject *object,
     }
 }
 
+/**
+ * tp_connection_manager_init_known_interfaces:
+ *
+ * Ensure that the known interfaces for TpConnectionManager have been set up.
+ * This is done automatically when necessary, but for correct
+ * overriding of library interfaces by local extensions, you should
+ * call this function before calling
+ * tp_proxy_or_subclass_hook_on_interface_add() with first argument
+ * %TP_TYPE_CONNECTION_MANAGER.
+ *
+ * Since: 0.7.32
+ */
+void
+tp_connection_manager_init_known_interfaces (void)
+{
+  static gsize once = 0;
+
+  if (g_once_init_enter (&once))
+    {
+      GType tp_type = TP_TYPE_CONNECTION_MANAGER;
+
+      tp_proxy_init_known_interfaces ();
+      tp_proxy_or_subclass_hook_on_interface_add (tp_type,
+          tp_cli_connection_manager_add_signals);
+      tp_proxy_subclass_add_error_mapping (tp_type,
+          TP_ERROR_PREFIX, TP_ERRORS, TP_TYPE_ERROR);
+
+      g_once_init_leave (&once, 1);
+    }
+}
+
 static void
 tp_connection_manager_class_init (TpConnectionManagerClass *klass)
 {
-  GType tp_type = TP_TYPE_CONNECTION_MANAGER;
   TpProxyClass *proxy_class = (TpProxyClass *) klass;
   GObjectClass *object_class = (GObjectClass *) klass;
   GParamSpec *param_spec;
 
+  tp_connection_manager_init_known_interfaces ();
+
   g_type_class_add_private (klass, sizeof (TpConnectionManagerPrivate));
 
   object_class->constructor = tp_connection_manager_constructor;
@@ -1400,10 +1455,6 @@ tp_connection_manager_class_init (TpConnectionManagerClass *klass)
   object_class->finalize = tp_connection_manager_finalize;
 
   proxy_class->interface = TP_IFACE_QUARK_CONNECTION_MANAGER;
-  tp_proxy_or_subclass_hook_on_interface_add (tp_type,
-      tp_cli_connection_manager_add_signals);
-  tp_proxy_subclass_add_error_mapping (tp_type,
-      TP_ERROR_PREFIX, TP_ERRORS, TP_TYPE_ERROR);
 
   /**
    * TpConnectionManager:info-source:
@@ -1586,8 +1637,13 @@ tp_connection_manager_new (TpDBusDaemon *dbus,
 gboolean
 tp_connection_manager_activate (TpConnectionManager *self)
 {
-  if (self->running)
-    return FALSE;
+  if (self->running || introspection_in_progress (self))
+    {
+      DEBUG ("already %s", self->running ? "running" : "introspecting");
+      return FALSE;
+    }
+
+  DEBUG ("calling ListProtocols");
 
   self->priv->listing_protocols = TRUE;
   tp_cli_connection_manager_call_list_protocols (self, -1,
@@ -1680,13 +1736,13 @@ tp_list_connection_managers_cm_ready (TpConnectionManager *cm,
 
 static void
 tp_list_connection_managers_got_names (TpDBusDaemon *bus_daemon,
-                                       const gchar **names,
+                                       const gchar * const *names,
                                        const GError *error,
                                        gpointer user_data,
                                        GObject *weak_object)
 {
   _ListContext *list_context = user_data;
-  const gchar **name_iter;
+  const gchar * const *name_iter;
 
   if (error != NULL)
     {
@@ -1742,7 +1798,7 @@ tp_list_connection_managers_got_names (TpDBusDaemon *bus_daemon,
     {
       list_context->getting_names = TRUE;
       list_context->refcount++;
-      tp_cli_dbus_daemon_call_list_names (bus_daemon, 2000,
+      tp_dbus_daemon_list_names (bus_daemon, 2000,
           tp_list_connection_managers_got_names, list_context,
           (GDestroyNotify) list_context_unref, weak_object);
     }
@@ -1790,7 +1846,7 @@ tp_list_connection_managers (TpDBusDaemon *bus_daemon,
   list_context->arr = NULL;
   list_context->cms_to_ready = 0;
 
-  tp_cli_dbus_daemon_call_list_activatable_names (bus_daemon, 2000,
+  tp_dbus_daemon_list_activatable_names (bus_daemon, 2000,
       tp_list_connection_managers_got_names, list_context,
       (GDestroyNotify) list_context_unref, weak_object);
 }
