@@ -183,35 +183,6 @@ tp_connection_continue_introspection (TpConnection *self)
     }
 }
 
-static void
-got_aliasing_flags (TpConnection *self,
-                    guint flags,
-                    const GError *error,
-                    gpointer user_data,
-                    GObject *weak_object)
-{
-  if (error == NULL)
-    {
-      DEBUG ("Introspected aliasing flags: 0x%x", flags);
-      self->priv->alias_flags = flags;
-    }
-  else
-    {
-      DEBUG ("GetAliasFlags(): %s", error->message);
-    }
-
-  tp_connection_continue_introspection (self);
-}
-
-static void
-introspect_aliasing (TpConnection *self)
-{
-  g_assert (self->priv->introspect_needed != NULL);
-
-  tp_cli_connection_interface_aliasing_call_get_alias_flags
-      (self, -1, got_aliasing_flags, NULL, NULL, NULL);
-}
-
 static void
 got_contact_attribute_interfaces (TpProxy *proxy,
                                   const GValue *value,
@@ -386,31 +357,6 @@ tp_connection_got_interfaces_cb (TpConnection *self,
                   func = introspect_contacts;
                   g_array_append_val (self->priv->introspect_needed, func);
                 }
-              else if (q == TP_IFACE_QUARK_CONNECTION_INTERFACE_ALIASING)
-                {
-                  /* call GetAliasFlags */
-                  func = introspect_aliasing;
-                  g_array_append_val (self->priv->introspect_needed,
-                      func);
-                }
-#if 0
-              else if (q == TP_IFACE_QUARK_CONNECTION_INTERFACE_AVATARS)
-                {
-                  /* call GetAvatarRequirements */
-                  func = introspect_avatars;
-                  g_array_append_val (self->priv->introspect_needed,
-                      func);
-                }
-              else if (q == TP_IFACE_QUARK_CONNECTION_INTERFACE_PRESENCE)
-                {
-                  /* call GetStatuses */
-                  func = introspect_presence;
-                  g_array_append_val (self->priv->introspect_needed,
-                      func);
-                }
-              /* if Privacy was stable, we'd also queue GetPrivacyModes
-               * here */
-#endif
             }
           else
             {
@@ -437,10 +383,12 @@ tp_connection_status_changed (TpConnection *self,
   g_object_notify ((GObject *) self, "status");
   g_object_notify ((GObject *) self, "status-reason");
 
-  if (status == TP_CONNECTION_STATUS_CONNECTED)
+  if (status == TP_CONNECTION_STATUS_CONNECTED &&
+      !self->priv->called_get_interfaces)
     {
       tp_cli_connection_call_get_interfaces (self, -1,
           tp_connection_got_interfaces_cb, NULL, NULL, NULL);
+      self->priv->called_get_interfaces = TRUE;
     }
 }
 
@@ -464,6 +412,7 @@ tp_connection_connection_error_cb (TpConnection *self,
 
 static void
 tp_connection_status_reason_to_gerror (TpConnectionStatusReason reason,
+                                       TpConnectionStatus prev_status,
                                        GError **error)
 {
   TpError code;
@@ -492,8 +441,21 @@ tp_connection_status_reason_to_gerror (TpConnectionStatusReason reason,
       break;
 
     case TP_CONNECTION_STATUS_REASON_NAME_IN_USE:
-      code = TP_ERROR_NOT_YOURS;
-      message = "Name in use";
+      if (prev_status == TP_CONNECTION_STATUS_CONNECTED)
+        {
+          code = TP_ERROR_CONNECTION_REPLACED;
+          message = "Connection replaced";
+        }
+      else
+        {
+          /* If the connection was with register=TRUE, we should ideally use
+           * REGISTRATION_EXISTS; but we can't actually tell that from here,
+           * so we'll have to rely on CMs supporting in-band registration
+           * (Gabble) to emit ConnectionError */
+          code = TP_ERROR_ALREADY_CONNECTED;
+          message = "Already connected (or if registering, registration "
+            "already exists)";
+        }
       break;
 
     case TP_CONNECTION_STATUS_REASON_CERT_NOT_PROVIDED:
@@ -552,6 +514,8 @@ tp_connection_status_changed_cb (TpConnection *self,
                                  gpointer user_data,
                                  GObject *weak_object)
 {
+  TpConnectionStatus prev_status = self->priv->status;
+
   /* GetStatus is called in the TpConnection constructor. If we don't have the
    * reply for this GetStatus call yet, ignore this signal StatusChanged in
    * order to run the interface introspection only one time. We will get the
@@ -568,7 +532,7 @@ tp_connection_status_changed_cb (TpConnection *self,
     {
       if (self->priv->connection_error == NULL)
         {
-          tp_connection_status_reason_to_gerror (reason,
+          tp_connection_status_reason_to_gerror (reason, prev_status,
               &(self->priv->connection_error));
         }
 
@@ -714,11 +678,12 @@ tp_connection_dispose (GObject *object)
 static void
 tp_connection_class_init (TpConnectionClass *klass)
 {
-  GType tp_type = TP_TYPE_CONNECTION;
   GParamSpec *param_spec;
   TpProxyClass *proxy_class = (TpProxyClass *) klass;
   GObjectClass *object_class = (GObjectClass *) klass;
 
+  tp_connection_init_known_interfaces ();
+
   g_type_class_add_private (klass, sizeof (TpConnectionPrivate));
 
   object_class->constructor = tp_connection_constructor;
@@ -730,10 +695,6 @@ tp_connection_class_init (TpConnectionClass *klass)
   /* If you change this, you must also change TpChannel to stop asserting
    * that its connection has a unique name */
   proxy_class->must_have_unique_name = TRUE;
-  tp_proxy_or_subclass_hook_on_interface_add (tp_type,
-      tp_cli_connection_add_signals);
-  tp_proxy_subclass_add_error_mapping (tp_type,
-      TP_ERROR_PREFIX, TP_ERRORS, TP_TYPE_ERROR);
 
   /**
    * TpConnection:status:
@@ -1171,13 +1132,13 @@ OUT:
 
 static void
 tp_list_connection_names_helper (TpDBusDaemon *bus_daemon,
-                                 const gchar **names,
+                                 const gchar * const *names,
                                  const GError *error,
                                  gpointer user_data,
                                  GObject *user_object)
 {
   _ListContext *list_context = user_data;
-  const gchar **iter;
+  const gchar * const *iter;
   /* array of borrowed strings */
   GPtrArray *bus_names;
   /* array of dup'd strings */
@@ -1276,7 +1237,7 @@ tp_list_connection_names (TpDBusDaemon *bus_daemon,
   list_context->callback = callback;
   list_context->user_data = user_data;
 
-  tp_cli_dbus_daemon_call_list_names (bus_daemon, 2000,
+  tp_dbus_daemon_list_names (bus_daemon, 2000,
       tp_list_connection_names_helper, list_context,
       list_context_free, weak_object);
 }
