@@ -29,13 +29,10 @@ G_BEGIN_DECLS
 gboolean _tp_dbus_daemon_get_name_owner (TpDBusDaemon *self, gint timeout_ms,
     const gchar *well_known_name, gchar **unique_name, GError **error);
 
-gboolean _tp_dbus_daemon_request_name (TpDBusDaemon *self,
-    const gchar *well_known_name, gboolean idempotent, GError **error);
-gboolean _tp_dbus_daemon_release_name (TpDBusDaemon *self,
-    const gchar *well_known_name, GError **error);
-
 void _tp_register_dbus_glib_marshallers (void);
 
+DBusGConnection *_tp_dbus_starter_bus_conn (GError **error);
+
 G_END_DECLS
 
 #endif /* __TP_INTERNAL_DBUS_GLIB_H__ */
