@@ -23,6 +23,8 @@
 
 #include <glib-object.h>
 
+#include <telepathy-glib/_gen/error-str.h>
+
 G_BEGIN_DECLS
 
 GQuark tp_errors_quark (void);
@@ -68,8 +70,19 @@ typedef enum {
     TP_ERROR_BUSY,
     TP_ERROR_NO_ANSWER,
     TP_ERROR_DOES_NOT_EXIST,
+    TP_ERROR_TERMINATED,
+    TP_ERROR_CONNECTION_REFUSED,
+    TP_ERROR_CONNECTION_FAILED,
+    TP_ERROR_CONNECTION_LOST,
+    TP_ERROR_ALREADY_CONNECTED,
+    TP_ERROR_CONNECTION_REPLACED,
+    TP_ERROR_REGISTRATION_EXISTS,
+    TP_ERROR_SERVICE_BUSY,
+    TP_ERROR_RESOURCE_UNAVAILABLE,
 } TpError;
 
+const gchar *tp_error_get_dbus_name (TpError error);
+
 G_END_DECLS
 
 #endif
