@@ -15,6 +15,7 @@
 
 #include "tests/lib/myassert.h"
 #include "tests/lib/simple-conn.h"
+#include "tests/lib/util.h"
 
 static GType bug15306_connection_get_type (void);
 
@@ -59,15 +60,8 @@ bug15306_conn_iface_init (gpointer g_iface,
 #undef IMPLEMENT
 }
 
-static int fail = 0;
 static GMainLoop *mainloop;
 
-static void
-myassert_failed (void)
-{
-  fail = 1;
-}
-
 static void
 on_status_changed (TpConnection *connection,
                    guint status,
@@ -116,15 +110,15 @@ main (int argc,
 
   MYASSERT (tp_base_connection_register (service_conn_as_base, "simple",
         &name, &conn_path, &error), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   conn = tp_connection_new (dbus, name, conn_path, &error);
   MYASSERT (conn != NULL, "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   MYASSERT (tp_connection_run_until_ready (conn, TRUE, &error, NULL),
       "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   /* disconnect the service_conn */
   MYASSERT (tp_cli_connection_connect_to_status_changed (conn,
@@ -141,5 +135,5 @@ main (int argc,
   g_free (name);
   g_free (conn_path);
 
-  return fail;
+  return 0;
 }
