@@ -18,14 +18,7 @@
 #include "examples/cm/echo-message-parts/chan.h"
 #include "examples/cm/echo-message-parts/conn.h"
 #include "tests/lib/myassert.h"
-
-static int fail = 0;
-
-static void
-myassert_failed (void)
-{
-  fail = 1;
-}
+#include "tests/lib/util.h"
 
 static guint received_count = 0;
 static guint last_received_id = 0;
@@ -200,28 +193,6 @@ on_messages_removed (TpChannel *chan,
     }
 }
 
-static GValue *
-slice_new_string (const char *string)
-{
-  GValue *ret = tp_g_value_slice_new (G_TYPE_STRING);
-
-  g_value_set_string (ret, string);
-  return ret;
-}
-
-static GValue *
-slice_new_byte_array (gconstpointer content,
-                      gsize length)
-{
-  GValue *ret = tp_g_value_slice_new (DBUS_TYPE_G_UCHAR_ARRAY);
-  GArray *arr = g_array_sized_new (FALSE, FALSE, 1, length);
-
-  g_array_append_vals (arr, content, length);
-  g_value_set_boxed (ret, arr);
-  g_array_free (arr, TRUE);
-  return ret;
-}
-
 int
 main (int argc,
       char **argv)
@@ -253,56 +224,49 @@ main (int argc,
 
   MYASSERT (tp_base_connection_register (service_conn_as_base, "example",
         &name, &conn_path, &error), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   conn = tp_connection_new (dbus, name, conn_path, &error);
   MYASSERT (conn != NULL, "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   MYASSERT (tp_connection_run_until_ready (conn, TRUE, &error, NULL),
       "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   contact_repo = tp_base_connection_get_handles (service_conn_as_base,
       TP_HANDLE_TYPE_CONTACT);
   MYASSERT (contact_repo != NULL, "");
 
   handle = tp_handle_ensure (contact_repo, "them@example.org", NULL, &error);
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
     {
       GHashTable *request = g_hash_table_new_full (g_str_hash, g_str_equal,
           NULL, (GDestroyNotify) tp_g_value_slice_free);
-      GValue *value;
 
-      value = tp_g_value_slice_new (G_TYPE_STRING);
-      g_value_set_static_string (value, TP_IFACE_CHANNEL_TYPE_TEXT);
       g_hash_table_insert (request, TP_IFACE_CHANNEL ".ChannelType",
-          value);
+          tp_g_value_slice_new_static_string (TP_IFACE_CHANNEL_TYPE_TEXT));
 
-      value = tp_g_value_slice_new (G_TYPE_UINT);
-      g_value_set_uint (value, TP_HANDLE_TYPE_CONTACT);
       g_hash_table_insert (request, TP_IFACE_CHANNEL ".TargetHandleType",
-          value);
+          tp_g_value_slice_new_uint (TP_HANDLE_TYPE_CONTACT));
 
-      value = tp_g_value_slice_new (G_TYPE_UINT);
-      g_value_set_uint (value, handle);
       g_hash_table_insert (request, TP_IFACE_CHANNEL ".TargetHandle",
-          value);
+          tp_g_value_slice_new_uint (handle));
 
       tp_cli_connection_interface_requests_run_create_channel (conn, -1,
           request, &chan_path, NULL, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       g_hash_table_destroy (request);
     }
 
   chan = tp_channel_new (conn, chan_path, TP_IFACE_CHANNEL_TYPE_TEXT,
       TP_HANDLE_TYPE_CONTACT, handle, &error);
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   tp_channel_run_until_ready (chan, &error, NULL);
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   MYASSERT (tp_cli_channel_type_text_connect_to_received (chan, on_received,
       g_object_ref (contact_repo), g_object_unref, NULL, NULL) != NULL, "");
@@ -329,7 +293,7 @@ main (int argc,
 
       tp_cli_dbus_properties_run_get_all (chan, -1,
           TP_IFACE_CHANNEL_INTERFACE_MESSAGES, &properties, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       g_print ("\n\n==== Examining properties ====\n\n");
 
@@ -381,7 +345,7 @@ main (int argc,
   while (received_count < 1 || message_received_count < 1)
     g_main_context_iteration (NULL, TRUE);
 
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
   MYASSERT (sent_count == 1, ": %u != 1", sent_count);
   MYASSERT (received_count == 1, ": %u != 1", received_count);
   MYASSERT (last_sent_type == TP_CHANNEL_TEXT_MESSAGE_TYPE_NORMAL,
@@ -421,7 +385,7 @@ main (int argc,
   while (received_count < 1 || message_received_count < 1)
     g_main_context_iteration (NULL, TRUE);
 
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
   MYASSERT (sent_count == 1, ": %u != 1", sent_count);
   MYASSERT (received_count == 1, ": %u != 1", received_count);
   MYASSERT (last_sent_type == TP_CHANNEL_TEXT_MESSAGE_TYPE_ACTION,
@@ -462,7 +426,7 @@ main (int argc,
   while (received_count < 1 || message_received_count < 1)
     g_main_context_iteration (NULL, TRUE);
 
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
   MYASSERT (sent_count == 1, ": %u != 1", sent_count);
   MYASSERT (received_count == 1, ": %u != 1", received_count);
   MYASSERT (last_sent_type == TP_CHANNEL_TEXT_MESSAGE_TYPE_NOTICE,
@@ -525,9 +489,12 @@ main (int argc,
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "alternative", slice_new_string ("main"));
-      g_hash_table_insert (part, "type", slice_new_string ("text/html"));
-      g_hash_table_insert (part, "content", slice_new_string (
+      g_hash_table_insert (part, "alternative",
+          tp_g_value_slice_new_string ("main"));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("text/html"));
+      g_hash_table_insert (part, "content",
+          tp_g_value_slice_new_string (
             "Here is a photo of a cat:<br />"
             "<img src=\"cid:lolcat\" alt=\"lol!\" /><br />"
             "It's in ur regression tests verifying ur designs!"
@@ -536,23 +503,27 @@ main (int argc,
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "alternative", slice_new_string ("main"));
-      g_hash_table_insert (part, "type", slice_new_string ("text/plain"));
+      g_hash_table_insert (part, "alternative",
+          tp_g_value_slice_new_string ("main"));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("text/plain"));
       g_hash_table_insert (part, "content",
-          slice_new_string (EXPECTED_TEXT));
+          tp_g_value_slice_new_string (EXPECTED_TEXT));
       g_ptr_array_add (send_parts, part);
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "identifier", slice_new_string ("lolcat"));
-      g_hash_table_insert (part, "type", slice_new_string ("image/jpeg"));
-      g_hash_table_insert (part, "content", slice_new_byte_array (
-            "\xff\xd8\xff\xe0\x00\x10JFIF\x00...", 14));
+      g_hash_table_insert (part, "identifier",
+          tp_g_value_slice_new_string ("lolcat"));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("image/jpeg"));
+      g_hash_table_insert (part, "content", tp_g_value_slice_new_bytes (
+            14, "\xff\xd8\xff\xe0\x00\x10JFIF\x00..."));
       g_ptr_array_add (send_parts, part);
 
       tp_cli_channel_interface_messages_run_send_message (chan, -1,
           send_parts, 0 /* flags */, &token, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       /* wait for pending events to be delivered */
       while (received_count < 1 || message_received_count < 1)
@@ -622,10 +593,14 @@ main (int argc,
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "alternative", slice_new_string ("main"));
-      g_hash_table_insert (part, "identifier", slice_new_string ("html"));
-      g_hash_table_insert (part, "type", slice_new_string ("text/html"));
-      g_hash_table_insert (part, "content", slice_new_string (
+      g_hash_table_insert (part, "alternative",
+          tp_g_value_slice_new_string ("main"));
+      g_hash_table_insert (part, "identifier",
+          tp_g_value_slice_new_string ("html"));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("text/html"));
+      g_hash_table_insert (part, "content",
+          tp_g_value_slice_new_string (
             "Here is a photo of a cat:<br />"
             "<img src=\"cid:lolcat\" alt=\"lol!\" /><br />"
             "It's in ur regression tests verifying ur designs!"
@@ -634,34 +609,43 @@ main (int argc,
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "alternative", slice_new_string ("main"));
-      g_hash_table_insert (part, "identifier", slice_new_string ("text"));
-      g_hash_table_insert (part, "type", slice_new_string ("text/plain"));
+      g_hash_table_insert (part, "alternative",
+          tp_g_value_slice_new_string ("main"));
+      g_hash_table_insert (part, "identifier",
+          tp_g_value_slice_new_string ("text"));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("text/plain"));
       g_hash_table_insert (part, "content",
-          slice_new_string (EXPECTED_TEXT));
+          tp_g_value_slice_new_string (EXPECTED_TEXT));
       g_ptr_array_add (send_parts, part);
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "identifier", slice_new_string ("jpeg"));
-      g_hash_table_insert (part, "alternative", slice_new_string ("lolcat"));
-      g_hash_table_insert (part, "type", slice_new_string ("image/jpeg"));
-      g_hash_table_insert (part, "content", slice_new_byte_array (
-            "\xff\xd8\xff\xe0\x00\x10JFIF\x00...", 14));
+      g_hash_table_insert (part, "identifier",
+          tp_g_value_slice_new_string ("jpeg"));
+      g_hash_table_insert (part, "alternative",
+          tp_g_value_slice_new_string ("lolcat"));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("image/jpeg"));
+      g_hash_table_insert (part, "content", tp_g_value_slice_new_bytes (
+            14, "\xff\xd8\xff\xe0\x00\x10JFIF\x00..."));
       g_ptr_array_add (send_parts, part);
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "identifier", slice_new_string ("png"));
-      g_hash_table_insert (part, "alternative", slice_new_string ("lolcat"));
-      g_hash_table_insert (part, "type", slice_new_string ("image/png"));
-      g_hash_table_insert (part, "content", slice_new_byte_array (
-            "\x89PNG\x0d\x0a\x1a\x0a\x00...", 12));
+      g_hash_table_insert (part, "identifier",
+          tp_g_value_slice_new_string ("png"));
+      g_hash_table_insert (part, "alternative",
+          tp_g_value_slice_new_string ("lolcat"));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("image/png"));
+      g_hash_table_insert (part, "content", tp_g_value_slice_new_bytes (
+            12, "\x89PNG\x0d\x0a\x1a\x0a\x00..."));
       g_ptr_array_add (send_parts, part);
 
       tp_cli_channel_interface_messages_run_send_message (chan, -1,
           send_parts, 0 /* flags */, &token, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       /* wait for pending events to be delivered */
       while (received_count < 1 || message_received_count < 1)
@@ -734,28 +718,31 @@ main (int argc,
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "type", slice_new_string ("text/plain"));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("text/plain"));
       g_hash_table_insert (part, "content",
-          slice_new_string ("I'm on a roll\n"));
+          tp_g_value_slice_new_string ("I'm on a roll\n"));
       g_ptr_array_add (send_parts, part);
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "type", slice_new_string ("text/plain"));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("text/plain"));
       g_hash_table_insert (part, "content",
-          slice_new_string ("I'm on a roll this time\n"));
+          tp_g_value_slice_new_string ("I'm on a roll this time\n"));
       g_ptr_array_add (send_parts, part);
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "type", slice_new_string ("text/plain"));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("text/plain"));
       g_hash_table_insert (part, "content",
-          slice_new_string ("I feel my luck could change\n"));
+          tp_g_value_slice_new_string ("I feel my luck could change\n"));
       g_ptr_array_add (send_parts, part);
 
       tp_cli_channel_interface_messages_run_send_message (chan, -1,
           send_parts, 0 /* flags */, &token, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       /* wait for pending events to be delivered */
       while (received_count < 1 || message_received_count < 1)
@@ -824,33 +811,43 @@ main (int argc,
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "type", slice_new_string ("text/plain"));
-      g_hash_table_insert (part, "alternative", slice_new_string ("alt"));
-      g_hash_table_insert (part, "lang", slice_new_string ("fr_CA@collabora"));
-      g_hash_table_insert (part, "content", slice_new_string (EXPECTED_TEXT));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("text/plain"));
+      g_hash_table_insert (part, "alternative",
+          tp_g_value_slice_new_string ("alt"));
+      g_hash_table_insert (part, "lang",
+          tp_g_value_slice_new_string ("fr_CA@collabora"));
+      g_hash_table_insert (part, "content",
+          tp_g_value_slice_new_string (EXPECTED_TEXT));
       g_ptr_array_add (send_parts, part);
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "type", slice_new_string ("text/plain"));
-      g_hash_table_insert (part, "alternative", slice_new_string ("alt"));
-      g_hash_table_insert (part, "lang", slice_new_string ("en_GB"));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("text/plain"));
+      g_hash_table_insert (part, "alternative",
+          tp_g_value_slice_new_string ("alt"));
+      g_hash_table_insert (part, "lang",
+          tp_g_value_slice_new_string ("en_GB"));
       g_hash_table_insert (part, "content",
-          slice_new_string ("we're fixing the colour of the video stream"));
+          tp_g_value_slice_new_string ("we're fixing the colour of the video stream"));
       g_ptr_array_add (send_parts, part);
 
       part = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
           (GDestroyNotify) tp_g_value_slice_free);
-      g_hash_table_insert (part, "type", slice_new_string ("text/plain"));
-      g_hash_table_insert (part, "alternative", slice_new_string ("alt"));
-      g_hash_table_insert (part, "lang", slice_new_string ("en_US"));
+      g_hash_table_insert (part, "content-type",
+          tp_g_value_slice_new_string ("text/plain"));
+      g_hash_table_insert (part, "alternative",
+          tp_g_value_slice_new_string ("alt"));
+      g_hash_table_insert (part, "lang",
+          tp_g_value_slice_new_string ("en_US"));
       g_hash_table_insert (part, "content",
-          slice_new_string ("we're fixing the color of the video stream"));
+          tp_g_value_slice_new_string ("we're fixing the color of the video stream"));
       g_ptr_array_add (send_parts, part);
 
       tp_cli_channel_interface_messages_run_send_message (chan, -1,
           send_parts, 0 /* flags */, &token, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       /* wait for pending events to be delivered */
       while (received_count < 1 || message_received_count < 1)
@@ -906,7 +903,7 @@ main (int argc,
 
       tp_cli_channel_interface_messages_run_get_pending_message_content (chan,
           -1, last_received_id, part_numbers, &ret, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       MYASSERT (g_hash_table_size (ret) == 2, ": %u",
           g_hash_table_size (ret));
@@ -935,7 +932,7 @@ main (int argc,
 
       tp_cli_channel_type_text_run_list_pending_messages (chan, -1,
           FALSE, &messages, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       g_print ("Freeing\n");
       g_boxed_free (TP_ARRAY_TYPE_PENDING_TEXT_MESSAGE_LIST, messages);
@@ -980,7 +977,7 @@ main (int argc,
 
       tp_cli_dbus_properties_run_get_all (chan, -1,
           TP_IFACE_CHANNEL_INTERFACE_MESSAGES, &properties, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       g_print ("\n\n==== Examining properties ====\n\n");
 
@@ -1032,7 +1029,7 @@ main (int argc,
 
       tp_cli_channel_type_text_run_acknowledge_pending_messages (chan, -1,
           msgid, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       g_array_free (msgid, TRUE);
     }
@@ -1045,7 +1042,7 @@ main (int argc,
 
       tp_cli_channel_type_text_run_list_pending_messages (chan, -1,
           TRUE, &messages, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       g_print ("Freeing\n");
       g_boxed_free (TP_ARRAY_TYPE_PENDING_TEXT_MESSAGE_LIST, messages);
@@ -1057,13 +1054,13 @@ main (int argc,
       GPtrArray *channels;
 
       MYASSERT (tp_cli_channel_run_close (chan, -1, &error, NULL), "");
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
       MYASSERT (tp_proxy_get_invalidated (chan) != NULL, "");
 
       /* assert that the channel has really gone */
       MYASSERT (tp_cli_connection_run_list_channels (conn, -1,
             &channels, &error, NULL), "");
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
       MYASSERT (channels->len == 0, "%u != 0", channels->len);
       g_boxed_free (TP_ARRAY_TYPE_CHANNEL_INFO_LIST, channels);
     }
@@ -1071,7 +1068,7 @@ main (int argc,
   g_print ("\n\n==== End of tests ====\n");
 
   MYASSERT (tp_cli_connection_run_disconnect (conn, -1, &error, NULL), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   tp_handle_unref (contact_repo, handle);
   g_object_unref (chan);
@@ -1088,5 +1085,5 @@ main (int argc,
   g_free (last_received_text);
   g_free (last_message_sent_token);
 
-  return fail;
+  return 0;
 }
